<template>
  <div class="person-card-list">
    <div class="query">
      <el-form :inline="true" :model="queryForm" class="query-form">
        <el-form-item label="驻勤点名称">
          <el-input style="width: 240px" v-model="queryForm.stationName" placeholder="请输入驻勤点名称"></el-input>
        </el-form-item>
        <el-form-item label="点名时间">
          <el-input style="width: 300px" v-model="queryForm.rollTime"></el-input>
        </el-form-item>
        <el-form-item label="点名发起人">
          <el-input style="width: 200px" v-model="queryForm.rollInitiator"></el-input>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="rollCall">督导点名</el-button>
          <el-button type="primary" plain @click="back">返回</el-button>
        </el-form-item>
        <el-form-item label="点名结果">
          <el-checkbox-group v-model="queryForm.callStatuses" @change="handleCheckedRollCallChange">
            <el-checkbox label="RollCallSuccess">点名成功</el-checkbox>
            <el-checkbox label="RollCallFailed">点名失败</el-checkbox>
            <el-checkbox label="DispatchSuccess">督导点名成功</el-checkbox>
            <el-checkbox label="DispatchFailed">督导点名失败</el-checkbox>
          </el-checkbox-group>
        </el-form-item>
      </el-form>
    </div>
    <el-main
      ref="container"
      class="list-container"
      v-infinite-scroll="load"
      infinite-scroll-disabled="disabled"
      infinite-scroll-distance="10"
    >
      <div
        v-for="(item, index) in rollCallEmployees"
        class="card"
        :class="[item === 3 || item === 4 ? 'card-mask' : '']"
        :key="item.rollCallId + index"
      >
        <div class="card-employeeName">{{ item.calledEmployeeName }}</div>
        <el-checkbox
          class="card-checkbox"
          v-model="item.active"
          :key="item.calledEmployeeId"
          :disabled="!item.active && rollCallEmployees.filter((x) => x.active).length >= 5"
          v-if="item.callStatusLabel.includes('失败')"
          @change="handleCheckedEmployeesChange"
        ></el-checkbox>
        <div :class="item.callStatusLabel.includes('失败') ? 'card-circle circle-failed' : 'card-circle circle-success'">
          {{ item.calledEmployeeName.slice(-2) }}
        </div>
        <div :class="item.callStatusLabel.includes('失败') ? 'card-statusLabel label-failed' : 'card-statusLabel lable-success'">
          {{ item.callStatusLabel }}
        </div>
      </div>
      <p class="bottom-tips" v-if="loading">加载中...</p>
      <p class="bottom-tips" v-if="noMore">没有更多了</p>
    </el-main>
    <el-dialog custom-class="dialog-roll-call" title="督导点名" :visible.sync="dialogVisible" width="23.333333%">
      <div
        class="btn-dispatch btn-dispatch-audio"
        :class="[callType === 'audio' ? 'btn-dispatch-active' : '']"
        @click="dispatch('audio')"
      >
        <i class="btn-dispatch-audio-img"></i>
        <span>音频调度</span>
      </div>
      <div
        class="btn-dispatch btn-dispatch-video"
        :class="[callType === 'video' ? 'btn-dispatch-active' : '']"
        @click="dispatch('video')"
      >
        <i class="btn-dispatch-video-img"></i>
        <span>视频调度</span>
      </div>
    </el-dialog>
    <!-- 音视频 -->
    <call-layer
      ref="callLayer"
      :member-list.sync="memberList"
      :type="callType"
      :yardman-type="yardmanType"
      :audio="stream.audio"
      :video="stream.video"
      roll-call
      :roll-call-id="rollCallId"
    ></call-layer>
  </div>
</template>

<script>
import CallLayer from "@/components/timApp/trtc/calling-index.vue";
import { getRollCallEmployees } from "@/api/roll-call-controller";
export default {
  name: "personCardList",
  components: {
    CallLayer,
  },
  props: {
    data: Object,
  },
  data() {
    return {
      loading: false,
      pageIndex: 0,
      noMore: false,
      queryForm: {
        stationId: this.data.stationId,
        stationName: this.data.stationName,
        rollTime: this.data.createdTime,
        rollInitiator: this.data.actionEmployeeName,
        callStatuses: [],
      },
      dialogVisible: false,
      callType: "",
      //调度类型：1视频调度 2 视频上拉：除了视频上拉传2，其他音频调度与视频调度都传1
      yardmanType: "1",
      memberList: [],
      rollCallEmployees: [], //所有点名人员
      stream: {
        audio: true,
        video: true,
      },
    };
  },
  computed: {
    rollCallId() {
      return this.data?.rollCallId;
    },
    disabled() {
      return this.loading || this.noMore;
    },
  },
  methods: {
    load() {
      this.noMore = false;
      this.pageIndex++;
      this.queryRollCallEmployees();
    },
    queryRollCallEmployees() {
      this.loading = true;
      let params = {
        pageIndex: this.pageIndex,
        pageSize: 10,
        forExport: true,
        beginDate: "",
        endDate: "",
        securityStationId: this.queryForm.stationId,
        rollCallId: this.rollCallId,
        superviseDepartIds: [],
        onlyForBeingCalledRecord: false,
        callTypes: ["RollCall"],
        callStatuses: this.queryForm.callStatuses, //点名状态: RollCallInit 点名中; RollCallSuccess 点名成功; RollCallFailed 点名失败; DispatchInit 督导中; DispatchSuccess 督导成功; DispatchFailed 督导失败
      };
      console.log("queryRollCallEmployeesParams", this.data, params);
      getRollCallEmployees(params)
        .then((res) => {
          console.log("queryRollCallEmployees", res);
          if (res.length === 0) {
            this.noMore = true;
          }
          const employeesSorted = [...res].sort(function (x, y) {
            // true values first
            return x.stationResponsible === y.stationResponsible ? 0 : x.stationResponsible ? -1 : 1;
          });
          const rollCallEmployees = [...employeesSorted].map((x) => {
            return {
              ...x,
              active: false,
            };
          });
          this.rollCallEmployees = [...this.rollCallEmployees, ...rollCallEmployees];
          this.$nextTick(() => {
            const container = this.$refs.container.$el;
            const lastChild = container.lastElementChild || container.lastChild; // 获取最后一个子元素
            // 获取父元素的位置和高度
            const parentRect = container.getBoundingClientRect();
            const childRect = lastChild.getBoundingClientRect();
            // 计算最后一个子元素底部与父元素底部的距离
            const distanceToParentBottom = parentRect.bottom - (childRect.bottom - childRect.height);
            if (distanceToParentBottom > 200 && res.length > 0) {
              this.load();
            }
          });
        })
        .catch((err) => {
          console.log(err);
        })
        .finally(() => {
          this.loading = false;
        });
    },
    handleCheckedRollCallChange() {
      // this.queryRollCallEmployees();
      // 重新查询
      this.rollCallEmployees = [];
      this.pageIndex = 0;
      this.load();
    },
    handleCheckedEmployeesChange(value) {
      console.log("CheckedEmployees", value);
    },
    rollCall() {
      console.log("rollCallEmployees", this.rollCallEmployees);
      if (this.rollCallEmployees && this.rollCallEmployees.filter((item) => item.active).length === 0) {
        this.$store.commit("showMessage", {
          message: "请选择督导点名人员！",
          type: "warning",
        });
        return;
      }
      this.dialogVisible = true;
    },
    back() {
      this.$emit("back");
    },
    dispatch(type) {
      this.dialogVisible = false;
      // set memberList;

      const memberList = this.rollCallEmployees.filter((item) => item.active);
      this.memberList = memberList.map((item) => {
        const { calledEmployeeId, calledEmployeeName, calledTencentUserId, calledOrganizationId } = item;
        return {
          ...item,
          id: calledEmployeeId,
          name: calledEmployeeName,
          tencentUserId: calledTencentUserId,
          organizationId: calledOrganizationId,
          state: "CONNECTING",
          action: "",
        };
      });
      console.log("memberList111", this.memberList);
      this.setCallProps(type).then(() => {
        this.$bus.$emit("video-call");
      });
    },
    setCallProps(type) {
      if (type === "video") {
        this.stream.video = true;
        this.stream.audio = true;
        this.callType = "video";
        this.yardmanType = "1";
      } else if (type === "audio") {
        this.stream.video = false;
        this.stream.audio = true;
        this.callType = "audio";
        this.yardmanType = "1";
      } else if (type === "videoLocalMute") {
        this.stream.video = false;
        this.stream.audio = true;
        this.callType = "video";
        this.yardmanType = "2";
      }
      return Promise.resolve();
    },
  },
  mounted() {},
};
</script>

<style scoped lang="scss">
.person-card-list {
  width: 100%;
  height: 100%;
  .query {
    width: 100%;
    height: 174px;
    background: #f5faff;
    box-shadow: 0px 2px 8px 0px rgba(0, 0, 0, 0.04);
    margin-bottom: 24px;
    padding: 24px;
    display: flex;
    flex-direction: column;
    flex-wrap: wrap;
    justify-content: space-between;
  }
  .list-container {
    width: 100%;
    height: calc(100% - 174px - 48px);
    display: grid;
    grid-template-columns: repeat(5, 1fr);
    padding: 0;
    overflow-x: hidden;
    overflow-y: auto;
    .card {
      width: 297px;
      height: 200px;
      margin-right: 20px;
      background: linear-gradient(180deg, #eff6ff 0%, #ffffff 100%);
      box-shadow: 0 8px 8px 0 rgba(0, 0, 0, 0.04);
      border-radius: 0;
      opacity: 1;
      border: 2px solid;
      border-image: linear-gradient(180deg, rgba(255, 255, 255, 1), rgba(255, 255, 255, 0)) 2 2;
      margin-bottom: 48px;
      position: relative;
      /*flex 布局*/
      display: flex;
      /*实现垂直居中*/
      align-items: center;
      /*实现水平居中*/
      justify-content: center;
      &-employeeName {
        position: absolute;
        top: 14px;
        left: 14px;
        font-size: 14px;
        font-family: "PingFang SC, PingFang SC";
        font-weight: 400;
        color: #333333;
      }
      &-checkbox {
        position: absolute;
        top: 14px;
        right: 14px;
      }
      &-statusLabel {
        font-size: 20px;
        font-family: "Source Han Sans CN, Source Han Sans CN";
        font-weight: 400;
        position: absolute;
        bottom: 14px;
      }
      &-circle {
        width: 93px;
        height: 93px;
        font-size: 24px;
        font-weight: 400;
        line-height: 93px;
        text-align: center;
        color: #ffffff;
        opacity: 1;
        // border-radius: 46px 46px 46px 46px;
      }
      .circle-failed {
        background: url("~@/assets/images/rollManage/点名失败.png");
        background-size: contain;
        // background: linear-gradient(133deg, #ed8925 0%, #f1b69e 100%);
      }
      .circle-success {
        background: url("~@/assets/images/rollManage/点名成功.png");
        background-size: contain;
        // background: linear-gradient(133deg, #0e70ff 0%, #6ba6ff 100%);
      }
      .label-failed {
        color: #f04545;
      }
      .label-success {
        color: #4cd93f;
      }
    }
  }
  .bottom-tips {
    color: #999;
    font-size: 16px;
    text-align: center;
    margin-bottom: 40px;
    width: 100%;
    grid-column: span 5;
  }
}
::v-deep .dialog-roll-call {
  .el-dialog__body {
    display: flex;
    align-items: center;
    justify-content: space-between;
    padding: 32px;
    .btn-dispatch {
      width: 176px;
      height: 192px;
      background: linear-gradient(180deg, #eff6ff 0%, #ffffff 100%);
      box-shadow: 0px 8px 10px 0px rgba(0, 0, 0, 0.04);
      border-radius: 4px 4px 4px 4px;
      border: 1px solid #bdcfde;
      cursor: pointer;
      display: flex;
      flex-direction: column;
      align-items: center;
      justify-content: center;
      &:hover {
        box-shadow: 0px 8px 10px 0px rgba(14, 112, 255, 0.16);
        border: 2px solid #0e70ff;
        color: #0e70ff;
      }
      &-audio {
        &-img {
          display: block;
          width: 80px;
          height: 80px;
          background: url("~@/assets/images/rollManage/语音.png") no-repeat;
          background-size: 100% 100%;
          margin-bottom: 24px;
        }
      }
      &-video {
        &-img {
          display: block;
          width: 80px;
          height: 80px;
          background: url("~@/assets/images/rollManage/视频.png") no-repeat;
          background-size: 100% 100%;
          margin-bottom: 24px;
        }
      }
    }
  }
}
</style>
